@@ -1,19 +1,3 @@
-# eulerr: Area-Proportional Euler and Venn Diagrams with Circles or Ellipses
-# Copyright (C) 2018 Johan Larsson <johanlarsson@outlook.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 #' Optimize Distance Between Circles Based On Overlap
 #'
 #' @param r1 radius of circle one
@@ -108,7 +92,10 @@ poly_clip <- function(a, b, op = c("intersection", "union", "minus", "xor")) {
       return(b)
     else if (!a0 && b0)
       return(a)
-    else
+    else if (!a0 && !b0) {
+      if (all(unlist(a) == unlist(b)))
+        return(a)
+    } else
       return(list())
   } else if (op == "minus") {
     if (!a0 && b0)
